import { ITextEditorOptions } from '@vscode/monaco-editor/esm/vs/platform/editor/common/editor';
import { IEditor as ICodeEditor, ScrollType } from '@vscode/monaco-editor/esm/vs/editor/common/editorCommon';
import { IBaseResourceInput, IEditorOptions } from '@workbench-stack/core';
export declare const DEFAULT_EDITOR_PART_OPTIONS: IEditorPartOptions;
export declare function getEditorPartOptions(config: IWorkbenchEditorConfiguration): IEditorPartOptions;
export interface IWorkbenchEditorConfiguration {
    workbench: {
        editor: IEditorPartConfiguration;
        iconTheme: string;
    };
}
interface IEditorPartConfiguration {
    showTabs?: boolean;
    highlightModifiedTabs?: boolean;
    tabCloseButton?: 'left' | 'right' | 'off';
    tabSizing?: 'fit' | 'shrink';
    focusRecentEditorAfterClose?: boolean;
    showIcons?: boolean;
    enablePreview?: boolean;
    enablePreviewFromQuickOpen?: boolean;
    closeOnFileDelete?: boolean;
    openPositioning?: 'left' | 'right' | 'first' | 'last';
    openSideBySideDirection?: 'right' | 'down';
    closeEmptyGroups?: boolean;
    revealIfOpen?: boolean;
    swipeToNavigate?: boolean;
    labelFormat?: 'default' | 'short' | 'medium' | 'long';
    restoreViewState?: boolean;
}
export interface IEditorPartOptions extends IEditorPartConfiguration {
    iconTheme?: string;
}
export declare class EditorOptions implements IEditorOptions {
    static create(settings: IEditorOptions): EditorOptions;
    preserveFocus: boolean | undefined;
    forceReload: boolean | undefined;
    revealIfVisible: boolean | undefined;
    revealIfOpened: boolean | undefined;
    pinned: boolean | undefined;
    index: number | undefined;
    inactive: boolean | undefined;
    ignoreError: boolean | undefined;
}
export declare class TextEditorOptions extends EditorOptions {
    private startLineNumber;
    private startColumn;
    private endLineNumber;
    private endColumn;
    private revealInCenterIfOutsideViewport;
    private editorViewState;
    static from(input?: IBaseResourceInput): TextEditorOptions | undefined;
    static create(options?: ITextEditorOptions): TextEditorOptions;
    hasOptionsDefined(): boolean;
    selection(startLineNumber: number, startColumn: number, endLineNumber?: number, endColumn?: number): EditorOptions;
    static fromEditor(editor: ICodeEditor, settings?: IEditorOptions): TextEditorOptions;
    apply(editor: ICodeEditor, scrollType: ScrollType): boolean;
    private applyViewState;
}
export {};
